==> ruby-1.8.0-i386-mingw32.tar.gz: usr/local/lib/ruby/1.8/i386-mingw32/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.8.0" or
    raise "ruby lib version (1.8.0) doesn't match executable version (#{RUBY_VERSION})"

  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-mingw32\Z', '')
  DESTDIR = '' unless defined? DESTDIR
  CONFIG = {}
  CONFIG["DESTDIR"] = DESTDIR
  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.0/ruby"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(DESTDIR)/usr/local/mingw/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["host_alias"] = "i686-pc-cygwin"
  CONFIG["target_alias"] = "i386-mingw32"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lwsock32 "
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "8"
  CONFIG["TEENY"] = "0"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["host"] = "i686-pc-cygwin"
  CONFIG["host_cpu"] = "i686"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "cygwin"
  CONFIG["target"] = "i386-pc-mingw32"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "mingw32"
  CONFIG["CC"] = "gcc -mno-cygwin"
  CONFIG["ac_ct_CC"] = ""
  CONFIG["CFLAGS"] = "-Os "
  CONFIG["LDFLAGS"] = ""
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "gcc -mno-cygwin -E"
  CONFIG["EGREP"] = "grep -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o "
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = ""
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = ""
  CONFIG["NM"] = "nm"
  CONFIG["ac_ct_NM"] = ""
  CONFIG["WINDRES"] = "windres"
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["DLLWRAP"] = "dllwrap"
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = " fileblocks$(U).o crypt$(U).o flock$(U).o isinf$(U).o acosh$(U).o erf$(U).o win32$(U).o"
  CONFIG["ALLOCA"] = ""
  CONFIG["XCFLAGS"] = ""
  CONFIG["XLDFLAGS"] = "-Wl,--stack,0x02000000 -L."
  CONFIG["DLDFLAGS"] = " -Wl,--enable-auto-import,--export-all"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = ""
  CONFIG["LDSHARED"] = "gcc -mno-cygwin -shared -s"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = "dll"
  CONFIG["LIBEXT"] = "a"
  CONFIG["LINK_SO"] = ""
  CONFIG["LIBPATHFLAG"] = " -L%s"
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.0/mingw.obj -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["ARCHFILE"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "gcc -mno-cygwin -shared -s"
  CONFIG["LIBRUBY_DLDFLAGS"] = " -Wl,--enable-auto-import,--export-all -Wl,--out-implib=$(LIBRUBY)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["rubyw_install_name"] = "rubyw"
  CONFIG["RUBYW_INSTALL_NAME"] = "rubyw"
  CONFIG["RUBY_SO_NAME"] = "msvcrt-$(RUBY_INSTALL_NAME)18"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
  CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
  CONFIG["LIBRUBY_ALIASES"] = ""
  CONFIG["LIBRUBY"] = "lib$(LIBRUBY_SO).a"
  CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
  CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = ""
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = ""
  CONFIG["COMMON_LIBS"] = "m"
  CONFIG["COMMON_MACROS"] = "WIN32_LEAN_AND_MEAN="
  CONFIG["COMMON_HEADERS"] = "windows.h winsock.h"
  CONFIG["EXPORT_PREFIX"] = ""
  CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
  CONFIG["arch"] = "i386-mingw32"
  CONFIG["sitearch"] = "i386-msvcrt"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-mingw32' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--includedir=/usr/local/mingw/include' '--enable-shared' '--enable-tcltk_stubs' '--with-tcllib=tclstub84' '--with-tklib=tkstub84' '--with-dbm-type=gdbm' '--with-opt-dir=/usr/local/mingw' '--with-gcc=gcc -mno-cygwin' 'CXX=g++ -mno-cygwin' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-mingw32'"
  CONFIG["NROFF"] = "/usr/bin/nroff"
  CONFIG["MANTYPE"] = "doc"
  CONFIG["LTLIBOBJS"] = " fileblocks$(U).lo crypt$(U).lo flock$(U).lo isinf$(U).lo acosh$(U).lo erf$(U).lo win32$(U).lo"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.0/mingw.obj"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val, config = CONFIG)
    val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
      if !(v = $1 || $2)
	'$'
      elsif key = config[v]
	config[v] = false
        Config::expand(key, config)
	config[v] = key
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
CROSS_COMPILING = nil unless defined? CROSS_COMPILING

==> ruby-1.8.1-i386-mingw32.tar.gz: usr/local/lib/ruby/1.8/i386-mingw32/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.8.1" or
    raise "ruby lib version (1.8.1) doesn't match executable version (#{RUBY_VERSION})"

  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-mingw32\Z', '')
  DESTDIR = '' unless defined? DESTDIR
  CONFIG = {}
  CONFIG["DESTDIR"] = DESTDIR
  CONFIG["srcdir"] = "/pub/ruby/18/dist/ruby-1.8.1/ruby"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ".exe"
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(DESTDIR)/usr/local/mingw/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = "i586-pc-linux-gnu"
  CONFIG["host_alias"] = "i686-pc-cygwin"
  CONFIG["target_alias"] = "i386-mingw32"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lwsock32 "
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "8"
  CONFIG["TEENY"] = "1"
  CONFIG["build"] = "i586-pc-linux-gnu"
  CONFIG["build_cpu"] = "i586"
  CONFIG["build_vendor"] = "pc"
  CONFIG["build_os"] = "linux-gnu"
  CONFIG["host"] = "i686-pc-cygwin"
  CONFIG["host_cpu"] = "i686"
  CONFIG["host_vendor"] = "pc"
  CONFIG["host_os"] = "cygwin"
  CONFIG["target"] = "i386-pc-mingw32"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "mingw32"
  CONFIG["CC"] = "gcc -mno-cygwin"
  CONFIG["ac_ct_CC"] = ""
  CONFIG["CFLAGS"] = "-Os "
  CONFIG["LDFLAGS"] = ""
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "gcc -mno-cygwin -E"
  CONFIG["EGREP"] = "grep -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o "
  CONFIG["YACC"] = "bison -y"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = ""
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = ""
  CONFIG["NM"] = "nm"
  CONFIG["ac_ct_NM"] = ""
  CONFIG["WINDRES"] = "windres"
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["DLLWRAP"] = "dllwrap"
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = " fileblocks$(U).o crypt$(U).o flock$(U).o acosh$(U).o win32$(U).o"
  CONFIG["ALLOCA"] = ""
  CONFIG["DLDFLAGS"] = " -Wl,--enable-auto-import,--export-all"
  CONFIG["ARCH_FLAG"] = ""
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = ""
  CONFIG["LDSHARED"] = "gcc -mno-cygwin -shared -s"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = "dll"
  CONFIG["LIBEXT"] = "a"
  CONFIG["LINK_SO"] = ""
  CONFIG["LIBPATHFLAG"] = " -L%s"
  CONFIG["RPATHFLAG"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/18/dist/ruby-1.8.1/m.obj -rfake"
  CONFIG["PREP"] = "fake.rb"
  CONFIG["ARCHFILE"] = ""
  CONFIG["XCFLAGS"] = ""
  CONFIG["XLDFLAGS"] = " -Wl,--stack,0x02000000 -L."
  CONFIG["LIBRUBY_LDSHARED"] = "gcc -mno-cygwin -shared -s"
  CONFIG["LIBRUBY_DLDFLAGS"] = " -Wl,--enable-auto-import,--export-all -Wl,--out-implib=$(LIBRUBY)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["rubyw_install_name"] = "rubyw"
  CONFIG["RUBYW_INSTALL_NAME"] = "rubyw"
  CONFIG["RUBY_SO_NAME"] = "msvcrt-$(RUBY_INSTALL_NAME)18"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
  CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
  CONFIG["LIBRUBY_ALIASES"] = ""
  CONFIG["LIBRUBY"] = "lib$(LIBRUBY_SO).a"
  CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
  CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = ""
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = ""
  CONFIG["COMMON_LIBS"] = "m"
  CONFIG["COMMON_MACROS"] = "WIN32_LEAN_AND_MEAN="
  CONFIG["COMMON_HEADERS"] = "windows.h winsock.h"
  CONFIG["EXPORT_PREFIX"] = ""
  CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
  CONFIG["arch"] = "i386-mingw32"
  CONFIG["sitearch"] = "i386-msvcrt"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--cache=config.cache' '--program-prefix=' '--target=i386-mingw32' '--host=i686-pc-cygwin' '--build=i586-pc-linux-gnu' '--includedir=/usr/local/mingw/include' '--enable-shared' '--enable-tcltk_stubs' '--with-tcllib=tclstub84' '--with-tklib=tkstub84' '--with-dbm-type=gdbm' '--with-opt-dir=/usr/local/mingw' '--with-gcc=gcc -mno-cygwin' 'CXX=g++ -mno-cygwin' 'CFLAGS=-Os' 'build_alias=i586-pc-linux-gnu' 'host_alias=i686-pc-cygwin' 'target_alias=i386-mingw32'"
  CONFIG["NROFF"] = "/usr/bin/nroff"
  CONFIG["MANTYPE"] = "doc"
  CONFIG["LTLIBOBJS"] = " fileblocks$(U).lo crypt$(U).lo flock$(U).lo acosh$(U).lo win32$(U).lo"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
  CONFIG["compile_dir"] = "/pub/ruby/18/dist/ruby-1.8.1/m.obj"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val, config = CONFIG)
    val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
      if !(v = $1 || $2)
	'$'
      elsif key = config[v]
	config[v] = false
        Config::expand(key, config)
	config[v] = key
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
CROSS_COMPILING = nil unless defined? CROSS_COMPILING
